@@ -57,7 +57,7 @@ public:
      * @param command the command that shall be executed for speaking
      * @param text the quoted text that can be inserted into the command
      */
-    QString prepareCommand(QString command, const QString &text,
+    QString prepareCommand(const QString &command, const QString &text,
                            const QString &filename, const QString &language);
 
 public Q_SLOTS:
