@@ -19,24 +19,18 @@
  ***************************************************************************/
 
 #include "texttospeechconfigurationwidget.h"
-#include <kconfig.h>
 
-#include <QtCore/QTextCodec>
-#include <QtGui/QLayout>
-#include <QtGui/QLabel>
-#include <QtGui/QLineEdit>
-#include <QtGui/QPushButton>
-#include <QtGui/QCheckBox>
+#include <QTextCodec>
+
+#include <KLocalizedString>
 
-#include <kcombobox.h>
-#include <klocale.h>
 #include "speech.h"
-#include <kurlrequester.h>
+#include "texttospeechsystem.h"
 
-TextToSpeechConfigurationWidget::TextToSpeechConfigurationWidget(QWidget *parent, const char *name)
+TextToSpeechConfigurationWidget::TextToSpeechConfigurationWidget(QWidget *parent, const QString &name)
     : QWizardPage(parent)
 {
-    setObjectName(QLatin1String(name));
+    setObjectName(name);
     setupUi(this);
     ttsSystem = new TextToSpeechSystem();
 
@@ -49,7 +43,7 @@ TextToSpeechConfigurationWidget::~TextToSpeechConfigurationWidget()
 
 void TextToSpeechConfigurationWidget::buildCodecList()
 {
-    QString local = i18nc("Local characterset", "Local") + QLatin1String(" (");
+    QString local = i18nc("Local characterset", "Local") + QStringLiteral(" (");
     local += QLatin1String(QTextCodec::codecForLocale()->name()) + QLatin1Char(')');
     characterCodingBox->addItem(local, Speech::Local);
     characterCodingBox->addItem(i18nc("Latin1 characterset", "Latin1"), Speech::Latin1);
@@ -60,18 +54,18 @@ void TextToSpeechConfigurationWidget::buildCodecList()
 
 void TextToSpeechConfigurationWidget::cancel()
 {
-    urlReq->setUrl(ttsSystem->ttsCommand);
+    urlReq->setUrl(QUrl::fromLocalFile(ttsSystem->ttsCommand));
     stdInButton->setChecked(ttsSystem->stdIn);
     characterCodingBox->setCurrentIndex(ttsSystem->codec);
-    useKttsd->setChecked(ttsSystem->useKttsd);
+    useQtSpeech->setChecked(ttsSystem->useQtSpeech);
 }
 
 void TextToSpeechConfigurationWidget::ok()
 {
-    ttsSystem->ttsCommand = urlReq->url().path();
+    ttsSystem->ttsCommand = urlReq->url().toLocalFile();
     ttsSystem->stdIn = stdInButton->isChecked();
     ttsSystem->codec = characterCodingBox->currentIndex();
-    ttsSystem->useKttsd = useKttsd->isChecked();
+    ttsSystem->useQtSpeech = useQtSpeech->isChecked();
 }
 
 TextToSpeechSystem *TextToSpeechConfigurationWidget::getTTSSystem() const
@@ -79,17 +73,17 @@ TextToSpeechSystem *TextToSpeechConfigurationWidget::getTTSSystem() const
     return ttsSystem;
 }
 
-void TextToSpeechConfigurationWidget::readOptions(KConfig *config, const QString &langGroup)
+void TextToSpeechConfigurationWidget::readOptions(const QString &langGroup)
 {
-    ttsSystem->readOptions(config, langGroup);
-    urlReq->setUrl(ttsSystem->ttsCommand);
+    ttsSystem->readOptions(langGroup);
+    urlReq->setUrl(QUrl::fromLocalFile(ttsSystem->ttsCommand));
     stdInButton->setChecked(ttsSystem->stdIn);
     characterCodingBox->setCurrentIndex(ttsSystem->codec);
-    useKttsd->setChecked(ttsSystem->useKttsd);
+    useQtSpeech->setChecked(ttsSystem->useQtSpeech);
 }
 
-void TextToSpeechConfigurationWidget::saveOptions(KConfig *config, const QString &langGroup)
+void TextToSpeechConfigurationWidget::saveOptions(const QString &langGroup)
 {
-    ttsSystem->saveOptions(config, langGroup);
+    ttsSystem->saveOptions(langGroup);
 }
 
